// Caddx Beetle camera mount
// Material: PETG/NYlon/Hard Flex. Extruder 0.4/layer 0.15
// Bend via hot air gun at 140C

// Parameters

// Render quality / Качество обработки
$fn=256; // [32:32:128]
// Diameter of mounting holes / Диаметр крепежных отверстий
mountholes = 2.6; // [0.8:0.05:3]
// Thickness of base mount / Толщина основания
mountheight = 0.9; // [0.2:0.05:2]
// Mount size / Положение посадочных отверстий
//mount_size=18.385; // BetaFPV frame
mount_size=18; // Eachine E010/E011 frame

module mount() {
    difference() {
        union() {
            // base from svg
            linear_extrude(height=mountheight,center=false) import("base.svg",convexity=10);
            // top layer from svg
            translate([0,0,mountheight]) linear_extrude(height=0.9,center=true) import("top.svg",convexity=10);
            // bottom camera mount
            translate([-16,0,0]) cube([16,4,0.3]);
            // side mount
            translate([-mount_size,mount_size,0]) cylinder(d=mountholes+2.2,h=mountheight);
            // rays mount
            translate([43.25,27,0]) cylinder(d=3.3,h=mountheight);
            // antenna mount
            translate([44.25,13,0]) cylinder(d=3.3,h=mountheight);    
        }
        // mount hole
        translate([-mount_size,mount_size,-1]) cylinder(d=mountholes,h=mountheight+2);
        // ray hole
        translate([43.25,27,-0.5]) cylinder(d=1.5,h=mountheight+2);
        // antenna hole
        translate([44.25,13,-0.5]) cylinder(d=1.7,h=mountheight+2);
    }
 }

difference() {
    union() {
        // lens outer
        translate([19.5,0,0]) hull() {
            translate([ 2, 2,0]) cylinder(d=8.8,h=2.1);
            translate([ 2,-2,0]) cylinder(d=8.8,h=2.1);
            translate([-2, 2,0]) cylinder(d=8.8,h=2.1);
            translate([-2,-2,0]) cylinder(d=8.8,h=2.1);
        }
        // antenna mount
        //translate([48,0,0]) cylinder(d=6.4,h=1.5);
        // parts
        mirror([0,0,0]) mount();
        mirror([0,1,0]) mount();
    }
        // front mount hole
        translate([0,0,-0.5]) cylinder(d=mountholes,h=mountheight+2);
        // lens hole
        translate([19.5,0,-1]) hull() {
            translate([-2, 2,0]) cylinder(d=6.4,h=4);
            translate([-2,-2,0]) cylinder(d=6.4,h=4);
            translate([ 2, 2,0]) cylinder(d=6.4,h=4);
            translate([ 2,-2,0]) cylinder(d=6.4,h=4);
        }
        // antenna mount hole
        //translate([48,0,-1]) cylinder(d=4.8,h=4);
}
